@@ -1,6 +1,5 @@
 from __future__ import annotations
 from typing import TYPE_CHECKING, Any, Callable, Dict, Generic, Literal, Type, TypeVar
-from .errors import InvalidAuth
 
 from yarl import URL
 
@@ -36,7 +35,7 @@ class Endpoint(Generic[ModalT, P]):
         url = self.url.with_query(**kwargs) if kwargs else self.url
         resp = await session.get(url, headers=headers)
         if resp.status is 401:
-            raise InvalidAuth()
+            raise Exception("LunarAPI » Error | Invalid Auth")
         return self.model(resp)
 
 def ep(route: str, model: Type[ModalT]) -> Callable[[Callable[P, Any]], Endpoint[ModalT, P]]:
@@ -51,16 +50,16 @@ class Client:
         self.__headers: Dict[Literal["Authorization"], str] = {"Authorization": f"Bearer {token}"}
         
         if token is None:
-            raise InvalidAuth()
+            raise Exception("LunarAPI » Error | Invalid Auth")
         
         if token == "":
-            raise InvalidAuth()
+            raise Exception("LunarAPI » Error | Invalid Auth")
 
     async def request(
         self, endpoint: Endpoint[ModalT, P], *args: P.args, **kwargs: P.kwargs
     ) -> ModalT:
         res = await endpoint.request(self._session, self.__headers, *args, **kwargs)
         if res.response.status is 401:
-            raise InvalidAuth()
+            raise Exception("LunarAPI » Error | Invalid Auth")
         
         return res
